@@ -17,7 +17,6 @@ from dagster import (
     Nothing,
     Out,
     PartitionsDefinition,
-    SolidExecutionContext,
     TableColumn,
     TableSchema,
 )
@@ -27,6 +26,7 @@ from dagster._core.definitions.events import CoercibleToAssetKeyPrefix
 from dagster._core.definitions.load_assets_from_modules import prefix_assets
 from dagster._core.definitions.metadata import RawMetadataValue
 from dagster._core.errors import DagsterInvalidSubsetError
+from dagster._legacy import SolidExecutionContext
 from dagster._utils.backcompat import experimental_arg_warning
 
 # dbt resource types that may be considered assets
@@ -284,7 +284,9 @@ def _dbt_nodes_to_assets(
 
     if use_build_command:
         deps = _get_deps(
-            dbt_nodes, selected_unique_ids, asset_resource_types=["model", "seed", "snapshot"]
+            dbt_nodes,
+            selected_unique_ids,
+            asset_resource_types=["model", "seed", "snapshot"],
         )
     else:
         deps = _get_deps(dbt_nodes, selected_unique_ids, asset_resource_types=["model"])
