@@ -11,7 +11,7 @@ from requests.exceptions import RequestException
 from dagster import Failure, Field, MetadataValue, StringSource, __version__
 from dagster import _check as check
 from dagster import get_dagster_logger, resource
-from dagster.utils.merger import deep_merge_dicts
+from dagster._utils.merger import deep_merge_dicts
 
 from .types import DbtCloudOutput
 
